@@ -1,6 +1,8 @@
 #[cfg(feature = "debug")]
 mod debug_tests;
+#[cfg(any(feature = "release"))]
+mod release_tests;
 #[cfg(feature = "report")]
 mod report_tests;
-mod utils;
 mod version;
+mod utils;
